@@ -13,8 +13,8 @@ use std::{env, fmt};
 
 use ansi_term::Colour;
 use cargo::core::compiler::{DefaultExecutor, Executor, RustcTargetData, Unit};
-use cargo::core::resolver::{HasDevUnits, ResolveOpts};
-use cargo::core::resolver::features::{ForceAllTargets, RequestedFeatures, CliFeatures};
+use cargo::core::resolver::HasDevUnits;
+use cargo::core::resolver::features::{ForceAllTargets, CliFeatures};
 use cargo::core::manifest::Target;
 use cargo::core::package_id::PackageId;
 use cargo::core::shell::Shell;
@@ -73,6 +73,7 @@ The `--profile test` flag can be used to check unit tests with the
 }
 
 #[derive(StructOpt, Debug)]
+#[allow(dead_code)]
 struct OptUdeps {
 	#[structopt(short, long, help("[cargo] No output printed to stdout"))]
 	quiet: bool,
@@ -269,7 +270,7 @@ impl OptUdeps {
 			)),
 		};
 		let mode = CompileMode::Check { test };
-		let pc = ProfileChecking::Unchecked;
+		let pc = ProfileChecking::LegacyTestOnly;
 		let compile_opts = clap_matches.compile_options(config, mode, Some(&ws), pc)?;
 		let requested_kinds = &compile_opts.build_config.requested_kinds;
 		let target_data = RustcTargetData::new(&ws, requested_kinds)?;
@@ -630,6 +631,7 @@ impl Executor for Exec {
 #[derive(Clone, Debug)]
 struct CmdInfo {
 	pkg :PackageId,
+	#[allow(dead_code)]
 	custom_build :bool,
 	crate_name :String,
 	crate_type :String,
@@ -1125,7 +1127,7 @@ trait ShellExt {
 
 impl ShellExt for Shell {
 	fn info<T: fmt::Display>(&mut self, message: T) -> CargoResult<()> {
-		self.print_ansi(
+		self.print_ansi_stderr(
 			format!(
 				"{} {}\n",
 				if self.err_supports_color() {
